@@ -1,10 +1,12 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
-
 require "log4r"
 
 # Add patches to log4r to support trace level
 require "vagrant/patches/log4r"
+require "vagrant/patches/net-ssh"
+require "vagrant/patches/rubygems"
+
 # Set our log levels and include trace
 require 'log4r/configurator'
 Log4r::Configurator.custom_levels(*(["TRACE"] + Log4r::Log4rConfig::LogLevels))
@@ -129,7 +131,11 @@ end
 # If the vagrant_ssl library exists, a recent version
 # of openssl is in use and its needed to load all the
 # providers needed
-if File.exist?(File.expand_path("vagrant/vagrant_ssl.so", __dir__))
+vagrant_ssl_locations = [
+  File.expand_path("vagrant/vagrant_ssl.so", __dir__),
+  File.expand_path("vagrant/vagrant_ssl.bundle", __dir__)
+]
+if vagrant_ssl_locations.any? { |f| File.exist?(f) }
   global_logger.debug("vagrant ssl helper found for loading ssl providers")
   begin
     require "vagrant/vagrant_ssl"
