@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "vagrant/util/template_renderer"
 
 module Vagrant
@@ -11,8 +14,8 @@ module Vagrant
         end
 
         def call(env)
-          if !env.has_key?(:config_validate) || env[:config_validate]
-            errors = env[:machine].config.validate(env[:machine])
+          if !env.key?(:config_validate) || env[:config_validate]
+            errors = env[:machine].config.validate(env[:machine], env[:ignore_provider])
 
             if errors && !errors.empty?
               raise Errors::ConfigInvalid,
