@@ -299,7 +299,12 @@ module Vagrant
       end
       # Sort the list to group like providers and properly ordered versions
       results.sort_by! do |box_result|
-        [box_result[0], box_result[2], Gem::Version.new(box_result[1]), box_result[3]]
+        [
+          box_result[0],
+          box_result[2],
+          Gem::Version.new(box_result[1]),
+          box_result[3] || :""
+        ]
       end
       results
     end
