@@ -1,6 +1,11 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'log4r'
 require 'optparse'
 
+require 'vagrant/util/experimental'
+
 module Vagrant
   # Manages the command line interface to Vagrant.
   class CLI < Vagrant.plugin("2", :command)
@@ -11,6 +16,9 @@ module Vagrant
       @logger = Log4r::Logger.new("vagrant::cli")
       @main_args, @sub_command, @sub_args = split_main_and_subcommand(argv)
 
+      ui = Vagrant::UI::Prefixed.new(env.ui, "vagrant")
+      @triggers = Vagrant::Plugin::V2::Trigger.new(env, env.vagrantfile.config.trigger, nil, ui)
+
       Util::CheckpointClient.instance.setup(env).check
       @logger.info("CLI: #{@main_args.inspect} #{@sub_command.inspect} #{@sub_args.inspect}")
     end
@@ -23,11 +31,23 @@ module Vagrant
         return 0
       end
 
+      if @sub_command == "login"
+        $stderr.puts "WARNING: This command has been deprecated and aliased to `vagrant cloud auth login`"
+      end
+
       # If we reached this far then we must have a subcommand. If not,
       # then we also just print the help and exit.
       command_plugin = nil
       if @sub_command
         command_plugin = Vagrant.plugin("2").manager.commands[@sub_command.to_sym]
+
+        if !command_plugin
+          alias_command = Alias.new(@env).commands[@sub_command.to_sym]
+
+          if alias_command
+            return alias_command.call(@sub_args)
+          end
+        end
       end
 
       if !command_plugin || !@sub_command
@@ -43,7 +63,9 @@ module Vagrant
       # Initialize and execute the command class, returning the exit status.
       result = 0
       begin
+        @triggers.fire(@sub_command, :before, nil, :command)
         result = command_class.new(@sub_args, @env).execute
+        @triggers.fire(@sub_command, :after, nil, :command)
       rescue Interrupt
         @env.ui.info(I18n.t("vagrant.cli_interrupt"))
         result = 1
