@@ -1,7 +1,10 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "vagrant/capability_host"
 
 module Vagrant
-  # This class handles host-OS specific interations. It is responsible for
+  # This class handles host-OS specific interactions. It is responsible for
   # detecting the proper host OS implementation and delegating capabilities
   # to plugins.
   #
@@ -9,6 +12,8 @@ module Vagrant
   class Host
     include CapabilityHost
 
+    autoload :Remote, "vagrant/host/remote"
+
     def initialize(host, hosts, capabilities, env)
       initialize_capabilities!(host, hosts, capabilities, env)
     end
