@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'thread'
 
 require 'childprocess'
@@ -90,10 +93,12 @@ module Vagrant
         process.io.stdout = stdout_writer
         process.io.stderr = stderr_writer
         process.duplex = true
+        process.leader = true if @options[:detach]
+        process.detach = true if @options[:detach]
 
         # Special installer-related things
         if Vagrant.in_installer?
-          installer_dir = ENV["VAGRANT_INSTALLER_EMBEDDED_DIR"].to_s.downcase
+          installer_dir = Vagrant.installer_embedded_dir.to_s.downcase
 
           # If we're in an installer on Mac and we're executing a command
           # in the installer context, then force DYLD_LIBRARY_PATH to look
@@ -123,6 +128,18 @@ module Vagrant
             @logger.info("Command not in installer, restoring original environment...")
             jailbreak(process.environment)
           end
+
+          # If running within an AppImage and calling external executable. When
+          # executable is external set the LD_LIBRARY_PATH to host values.
+          if ENV["VAGRANT_APPIMAGE"]
+            embed_path = Pathname.new(Vagrant.installer_embedded_dir).expand_path.to_s
+            exec_path = Pathname.new(@command[0]).expand_path.to_s
+            if !exec_path.start_with?(embed_path) && ENV["VAGRANT_APPIMAGE_HOST_LD_LIBRARY_PATH"]
+              @logger.info("Detected AppImage environment and request to external binary. Updating library path.")
+              @logger.debug("Setting LD_LIBRARY_PATH to #{ENV["VAGRANT_APPIMAGE_HOST_LD_LIBRARY_PATH"]}")
+              process.environment["LD_LIBRARY_PATH"] = ENV["VAGRANT_APPIMAGE_HOST_LD_LIBRARY_PATH"].to_s
+            end
+          end
         else
           @logger.info("Vagrant not running in installer, restoring original environment...")
           jailbreak(process.environment)
@@ -146,6 +163,12 @@ module Vagrant
           raise LaunchError.new(ex.message)
         end
 
+        # If running with the detach option, no need to capture IO or
+        # ensure program exists.
+        if @options[:detach]
+          return
+        end
+
         # Make sure the stdin does not buffer
         process.io.stdin.sync = true
 
@@ -185,7 +208,7 @@ module Vagrant
               next if data.empty?
 
               io_name = r == stdout ? :stdout : :stderr
-              @logger.debug("#{io_name}: #{data.chomp}")
+              @logger.trace("#{io_name}: #{data.chomp}")
 
               io_data[io_name] += data
               yield io_name, data if block_given? && notify_table[io_name]
@@ -233,7 +256,7 @@ module Vagrant
           # Log it out and accumulate
           io_name = io == stdout ? :stdout : :stderr
           io_data[io_name] += extra_data
-          @logger.debug("#{io_name}: #{extra_data.chomp}")
+          @logger.trace("#{io_name}: #{extra_data.chomp}")
 
           # Yield to any listeners any remaining data
           yield io_name, extra_data if block_given? && notify_table[io_name]
@@ -249,7 +272,7 @@ module Vagrant
         # Return an exit status container
         return Result.new(process.exit_code, io_data[:stdout], io_data[:stderr])
       ensure
-        if process && process.alive?
+        if process && process.alive? && !@options[:detach]
           # Make sure no matter what happens, the process exits
           process.stop(2)
         end
