@@ -1,7 +1,10 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'ostruct'
 require "pathname"
 
-require 'erubis'
+require 'erubi'
 
 module Vagrant
   module Util
@@ -50,7 +53,7 @@ module Vagrant
         end
       end
 
-      # Renders the template using the class intance as the binding. Because the
+      # Renders the template using the class instance as the binding. Because the
       # renderer inherits from `OpenStruct`, additional view variables can be
       # added like normal accessors.
       #
@@ -73,10 +76,10 @@ module Vagrant
       #
       # @return [String]
       def render_string
-        Erubis::Eruby.new(template, trim: true).result(binding)
+        binding.eval(Erubi::Engine.new(template, trim: true).src)
       end
 
-      # Returns the full path to the template, taking into accoun the gem directory
+      # Returns the full path to the template, taking into account the gem directory
       # and adding the `.erb` extension to the end.
       #
       # @return [String]
