@@ -1,3 +1,8 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
+require "vagrant/plugin/state_file"
+
 module VagrantPlugins
   module CommandPlugin
     module Command
@@ -9,11 +14,6 @@ module VagrantPlugins
         # @param [Object] callable the Middleware callable
         # @param [Hash] env Extra environment hash that is merged in.
         def action(callable, env=nil)
-          env = {
-            :gem_helper => GemHelper.new(@env.gems_path),
-            :plugin_state_file => StateFile.new(@env.home_path.join("plugins.json"))
-          }.merge(env || {})
-
           @env.action_runner.run(callable, env)
         end
       end
