@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'optparse'
 
 require_relative "base"
@@ -9,6 +12,9 @@ module VagrantPlugins
         def execute
           opts = OptionParser.new do |o|
             o.banner = "Usage: vagrant plugin list [-h]"
+
+            # Stub option to allow Vagrantfile loading
+            o.on("--local", "Include local project plugins"){|_|}
           end
 
           # Parse the options
