@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'optparse'
 
 require_relative "base"
@@ -10,9 +13,14 @@ module VagrantPlugins
         include MixinInstallOpts
 
         def execute
+          options = {}
           opts = OptionParser.new do |o|
             o.banner = "Usage: vagrant plugin update [names...] [-h]"
             o.separator ""
+
+            o.on("--local", "Update plugin in local project") do |l|
+              options[:env_local] = l
+            end
           end
 
           # Parse the options
@@ -22,6 +30,7 @@ module VagrantPlugins
           # Update the gem
           action(Action.action_update, {
             plugin_name:        argv,
+            env_local:          options[:env_local]
           })
 
           # Success, exit status 0
