@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'optparse'
 
 module VagrantPlugins
@@ -15,7 +18,7 @@ module VagrantPlugins
           o.banner = "Usage: vagrant provision [vm-name] [--provision-with x,y,z]"
 
           o.on("--provision-with x,y,z", Array,
-                    "Enable only certain provisioners, by type.") do |list|
+                    "Enable only certain provisioners, by type or by name.") do |list|
             options[:provision_types] = list.map { |type| type.to_sym }
           end
         end
