@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'optparse'
 
 module VagrantPlugins
@@ -32,8 +35,9 @@ module VagrantPlugins
               next
             end
 
+            vm.ui.output("", prefix: true)
             snapshots.each do |snapshot|
-              vm.ui.output(snapshot, prefix: false)
+              vm.ui.detail(snapshot, prefix: false)
             end
           end
 
