@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'optparse'
 
 module VagrantPlugins
@@ -9,7 +12,7 @@ module VagrantPlugins
 
       def execute
         opts = OptionParser.new do |o|
-          o.banner = "Usage: vagrant status [name]"
+          o.banner = "Usage: vagrant status [name|id]"
         end
 
         # Parse the options
