@@ -1,3 +1,8 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
+require "shellwords"
+
 module VagrantPlugins
   module CommunicatorWinRM
     module CommandFilters
@@ -6,14 +11,14 @@ module VagrantPlugins
         def filter(command)
           # mkdir -p /some/dir
           # mkdir /some/dir
-          cmd_parts = command.strip.split(/\s+/)
+          cmd_parts = Shellwords.split(command.strip)
           dir = cmd_parts.pop
           while !dir.nil? && dir.start_with?('-')
             dir = cmd_parts.pop
           end
           # This will ignore any -p switches, which are redundant in PowerShell,
           # and ambiguous in PowerShell 4+
-          return "mkdir #{dir} -force"
+          return "mkdir \"#{dir}\" -force"
         end
 
         def accept?(command)
