@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 module VagrantPlugins
   module GuestDebian
     module Cap
@@ -5,9 +8,9 @@ module VagrantPlugins
         def self.nfs_client_install(machine)
           comm = machine.communicate
           comm.sudo <<-EOH.gsub(/^ {12}/, '')
-            set -e
             apt-get -yqq update
             apt-get -yqq install nfs-common portmap
+            exit $?
           EOH
         end
       end
