@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "vagrant"
 
 module VagrantPlugins
@@ -6,7 +9,7 @@ module VagrantPlugins
       name "DragonFly BSD guest"
       description "DragonFly BSD guest support."
 
-      guest(:dragonflybsd, :bsd) do
+      guest(:dragonflybsd, :freebsd) do
         require_relative "guest"
         Guest
       end
