@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'vagrant/util/template_renderer'
 
 module VagrantPlugins
@@ -7,7 +10,7 @@ module VagrantPlugins
     # Contributed by Kenneth Vestergaard <kvs@binarysolutions.dk>
     class Guest < Vagrant.plugin("2", :guest)
       def detect?(machine)
-        machine.communicate.test("uname -s | grep 'FreeBSD'", {:shell => "sh"})
+        machine.communicate.test("uname -s | grep 'FreeBSD'", {shell: "sh"})
       end
     end
   end
