@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "vagrant"
 
 module VagrantPlugins
@@ -6,17 +9,17 @@ module VagrantPlugins
       name "Gentoo guest"
       description "Gentoo guest support."
 
-      guest("gentoo", "linux") do
-        require File.expand_path("../guest", __FILE__)
+      guest(:gentoo, :linux) do
+        require_relative "guest"
         Guest
       end
 
-      guest_capability("gentoo", "change_host_name") do
+      guest_capability(:gentoo, :change_host_name) do
         require_relative "cap/change_host_name"
         Cap::ChangeHostName
       end
 
-      guest_capability("gentoo", "configure_networks") do
+      guest_capability(:gentoo, :configure_networks) do
         require_relative "cap/configure_networks"
         Cap::ConfigureNetworks
       end
