@@ -1,18 +1,20 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 module VagrantPlugins
   module GuestLinux
     module Cap
       module ChooseAddressableIPAddr
         def self.choose_addressable_ip_addr(machine, possible)
-          machine.communicate.tap do |comm|
-            possible.each do |ip|
-              command = "ping -c1 -w1 -W1 #{ip}"
-              if comm.test(command)
-                return ip
-              end
+          comm = machine.communicate
+
+          possible.each do |ip|
+            if comm.test("ping -c1 -w1 -W1 #{ip}")
+              return ip
             end
           end
 
-          nil
+          return nil
         end
       end
     end
