@@ -1,6 +1,9 @@
-require 'tempfile'
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
 
-require "vagrant/util/template_renderer"
+require "tempfile"
+
+require_relative "../../../../lib/vagrant/util/template_renderer"
 
 module VagrantPlugins
   module GuestNixos
@@ -16,13 +19,16 @@ module VagrantPlugins
 
         # Upload a file.
         def self.upload(machine, content, remote_path)
-          local_temp = Tempfile.new("vagrant-upload")
-          local_temp.binmode
-          local_temp.write(content)
-          local_temp.close
           remote_temp = mktemp(machine)
-          machine.communicate.upload(local_temp.path, "#{remote_temp}")
-          local_temp.delete
+
+          Tempfile.open("vagrant-nixos-change-host-name") do |f|
+            f.binmode
+            f.write(content)
+            f.fsync
+            f.close
+            machine.communicate.upload(f.path, "#{remote_temp}")
+          end
+
           machine.communicate.sudo("mv #{remote_temp} #{remote_path}")
         end
 
