@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 module VagrantPlugins
   module GuestPhoton
     module Cap
@@ -18,7 +21,7 @@ module VagrantPlugins
             device = interfaces[network[:interface]]
             command =  "ifconfig #{device}"
             command << " #{network[:ip]}" if network[:ip]
-            command << " netmast #{network[:netmask]}" if network[:netmask]
+            command << " netmask #{network[:netmask]}" if network[:netmask]
             commands << command
           end
 
