@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "tempfile"
 
 require_relative "../../../../lib/vagrant/util/template_renderer"
@@ -19,9 +22,12 @@ module VagrantPlugins
 
           # Check if NetworkManager is installed on the system
           nmcli_installed = nmcli?(comm)
+          net_configs = machine.config.vm.networks.map do |type, opts|
+            opts if type.to_s.end_with?("_network")
+          end.compact
           networks.each.with_index do |network, i|
             network[:device] = interfaces[network[:interface]]
-            extra_opts = machine.config.vm.networks[i].last.dup
+            extra_opts = net_configs[i] ? net_configs[i].dup : {}
 
             if nmcli_installed
               # Now check if the device is actively being managed by NetworkManager
@@ -47,7 +53,7 @@ module VagrantPlugins
 
             # Render a new configuration
             entry = TemplateRenderer.render("guests/redhat/network_#{network[:type]}",
-              options: network.merge(extra_opts),
+              options: extra_opts.merge(network),
             )
 
             # Upload the new configuration
