@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "log4r"
 
 require_relative "../guest_network"
@@ -9,10 +12,6 @@ module VagrantPlugins
         @@logger = Log4r::Logger.new("vagrant::guest::windows::configure_networks")
 
         def self.configure_networks(machine, networks)
-          if machine.config.vm.communicator != :winrm
-            raise Errors::NetworkWinRMRequired
-          end
-
           @@logger.debug("Networks: #{networks.inspect}")
 
           guest_network = GuestNetwork.new(machine.communicate)
