@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "vagrant/util/template_renderer"
 require "base64"
 
@@ -6,7 +9,7 @@ module VagrantPlugins
     module Cap
       class MountSharedFolder
         def self.mount_virtualbox_shared_folder(machine, name, guestpath, options)
-          mount_shared_folder(machine, name, guestpath, "\\\\vboxsrv\\")
+          mount_shared_folder(machine, name, guestpath, "\\\\vboxsvr\\")
         end
 
         def self.mount_vmware_shared_folder(machine, name, guestpath, options)
@@ -22,7 +25,7 @@ module VagrantPlugins
             # Ensure password is scrubbed
             Vagrant::Util::CredentialScrubber.sensitive(options[:smb_password])
           end
-          machine.communicate.execute("cmdkey /add:#{options[:smb_host]} /user:#{options[:smb_username]} /pass:#{options[:smb_password]}", {shell: :powershell, elevated: true})
+          machine.communicate.execute("cmdkey /add:#{options[:smb_host]} /user:#{options[:smb_username]} /pass:\"#{options[:smb_password]}\"", {shell: :powershell, elevated: true})
           mount_shared_folder(machine, name, guestpath, "\\\\#{options[:smb_host]}\\")
         end
 
