@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "pathname"
 require "tmpdir"
 
@@ -28,7 +31,7 @@ module VagrantPlugins
           args << "Bypass"
           args << "-NoExit"
           args << "-EncodedCommand"
-          args << ::WinRM::PowershellScript.new(command).encoded
+          args << encoded(command)
           if ps_info[:extra_args]
             args << ps_info[:extra_args]
           end
@@ -36,6 +39,11 @@ module VagrantPlugins
           # Launch it
           Vagrant::Util::SafeExec.exec("powershell", *args)
         end
+
+        def self.encoded(script)
+          encoded_script = script.encode('UTF-16LE', 'UTF-8')
+          Base64.strict_encode64(encoded_script)
+        end
       end
     end
   end
