@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require 'log4r'
 
 require 'vagrant/util/busy'
@@ -66,6 +69,27 @@ module VagrantPlugins
                 break
               end
             end
+          elsif Vagrant::Util::Platform.wsl?
+            if !Vagrant::Util::Platform.wsl_windows_access?
+              @logger.error("No user Windows access defined for the Windows Subsystem for Linux. This is required for VirtualBox.")
+              raise Vagrant::Errors::WSLVirtualBoxWindowsAccessError
+            end
+            @logger.debug("Linux platform detected but executing within WSL. Locating VBoxManage.")
+            @vboxmanage_path = Vagrant::Util::Which.which("VBoxManage") || Vagrant::Util::Which.which("VBoxManage.exe")
+            if !@vboxmanage_path
+              # If we still don't have one, try to find it using common locations
+              drive = "/mnt/c"
+              [
+                "#{drive}/Program Files/Oracle/VirtualBox",
+                "#{drive}/Program Files (x86)/Oracle/VirtualBox"
+              ].each do |maybe|
+                path = File.join(maybe, "VBoxManage.exe")
+                if File.file?(path)
+                  @vboxmanage_path = path
+                  break
+                end
+              end
+            end
           end
 
           # Fall back to hoping for the PATH to work out
@@ -347,6 +371,21 @@ module VagrantPlugins
         def vm_exists?(uuid)
         end
 
+        # Returns a hash of information about a given virtual machine
+        #
+        # @param [String] uuid
+        # @return [Hash] info
+        def show_vm_info
+          info = {}
+          execute('showvminfo', @uuid, '--machinereadable', retryable: true).split("\n").each do |line|
+            parts = line.partition('=')
+            key = parts.first.gsub('"', '')
+            value = parts.last.gsub('"', '')
+            info[key] = value
+          end
+          info
+        end
+
         # Execute the given subcommand for VBoxManage and return the output.
         def execute(*command, &block)
           # Get the options hash if it exists
@@ -424,7 +463,9 @@ module VagrantPlugins
           end
 
           # Append in the options for subprocess
-          command << { notify: [:stdout, :stderr] }
+          # NOTE: We include the LANG env var set to C to prevent command output
+          #       from being localized
+          command << { notify: [:stdout, :stderr], env: env_lang}
 
           Vagrant::Util::Busy.busy(int_callback) do
             Vagrant::Util::Subprocess.execute(@vboxmanage_path, *command, &block)
@@ -433,6 +474,56 @@ module VagrantPlugins
           raise Vagrant::Errors::VBoxManageLaunchError,
             message: e.to_s
         end
+
+        private
+
+        # List of LANG values to attempt to use
+        LANG_VARIATIONS = %w(C.UTF-8 C.utf8 en_US.UTF-8 en_US.utf8 C POSIX).map(&:freeze).freeze
+
+        # By default set the LANG to C. If the host has the locale command
+        # available, check installed locales and verify C is included (or
+        # use C variant if available).
+        def env_lang
+          # If already set, just return immediately
+          return @env_lang if @env_lang
+
+          # Default the LANG to C
+          @env_lang = {LANG: "C"}
+
+          # If the locale command is not available, return default
+          return @env_lang if !Vagrant::Util::Which.which("locale")
+
+          if defined?(@@env_lang)
+            return @env_lang = @@env_lang
+          end
+
+          @logger.debug("validating LANG value for virtualbox cli commands")
+          # Get list of available locales on the system
+          result = Vagrant::Util::Subprocess.execute("locale", "-a")
+
+          # If the command results in an error, just log the error
+          # and return the default value
+          if result.exit_code != 0
+            @logger.warn("locale command failed (exit code: #{result.exit_code}): #{result.stderr}")
+            return @env_lang
+          end
+          available = result.stdout.lines.map(&:chomp).find_all { |l|
+            l == "C" || l == "POSIX" || l.start_with?("C.") || l.start_with?("en_US.")
+          }
+          @logger.debug("list of available C locales: #{available.inspect}")
+
+          # Attempt to find a valid LANG from locale list
+          lang = LANG_VARIATIONS.detect { |l| available.include?(l) }
+
+          if lang
+            @logger.debug("valid variation found for LANG value: #{lang}")
+            @env_lang[:LANG] = lang
+            @@env_lang = @env_lang
+          end
+
+          @logger.debug("LANG value set: #{@env_lang[:LANG].inspect}")
+          @env_lang
+        end
       end
     end
   end
