@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "vagrant/util/scoped_hash_override"
 
 module VagrantPlugins
@@ -15,6 +18,7 @@ module VagrantPlugins
             if type == :forwarded_port
               guest_port = options[:guest]
               host_port  = options[:host]
+              host_ip    = options[:host_ip]
               protocol   = options[:protocol] || "tcp"
               options    = scoped_hash_override(options, :virtualbox)
               id         = options[:id]
@@ -22,7 +26,8 @@ module VagrantPlugins
               # If the forwarded port was marked as disabled, ignore.
               next if options[:disabled]
 
-              mappings[host_port.to_s + protocol.to_s] =
+              key = "#{host_ip}#{protocol}#{host_port}"
+              mappings[key] =
                 Model::ForwardedPort.new(id, host_port, guest_port, options)
             end
           end
