@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "log4r"
 require "vagrant"
 
@@ -5,6 +8,11 @@ module VagrantPlugins
   module CFEngine
     class Provisioner < Vagrant.plugin("2", :provisioner)
       def provision
+        if @machine.config.vm.communicator == :winrm
+          raise Vagrant::Errors::ProvisionerWinRMUnsupported,
+            name: "cfengine"
+        end
+
         @logger = Log4r::Logger.new("vagrant::plugins::cfengine")
 
         @logger.info("Checking for CFEngine installation...")
@@ -43,7 +51,7 @@ module VagrantPlugins
             color = type == :stdout ? :green : :red
             @machine.ui.info(
               data,
-              :color => color, :new_line => false, :prefix => false)
+              color: color, new_line: false, prefix: false)
           end
         end
       end
