@@ -1,3 +1,8 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
+require "pathname"
+
 require "vagrant"
 
 module VagrantPlugins
@@ -15,10 +20,10 @@ module VagrantPlugins
           errors << I18n.t("vagrant.provisioners.file.no_dest_file")
         end
         if source
-          s = File.expand_path(source)
-          if ! File.exist?(s)
+          s = Pathname.new(source).expand_path(machine.env.root_path)
+          if !s.exist?
             errors << I18n.t("vagrant.provisioners.file.path_invalid",
-                              path: s)
+                              path: s.to_s)
           end
         end
 
