@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "digest/md5"
 
 require "log4r"
@@ -132,6 +135,22 @@ module VagrantPlugins
             @machine.communicate.upload(local_hiera_path, @hiera_config_path)
           end
 
+          # Build up the structured custom facts if we have any
+          # With structured facts on, we assume the config.facter is yaml.
+          if config.structured_facts && !config.facter.empty?
+            @facter_config_path = "/etc/puppetlabs/facter/facts.d/vagrant_facts.yaml"
+            if windows?
+              @facter_config_path = "/ProgramData/PuppetLabs/facter/facts.d/vagrant_facts.yaml"
+            end
+            t = Tempfile.new("vagrant_facts.yaml")
+            t.write(config.facter.to_yaml)
+            t.close()
+            @machine.communicate.tap do |comm|
+              comm.upload(t.path, File.join(@config.temp_dir, "vagrant_facts.yaml"))
+              comm.sudo("cp #{config.temp_dir}/vagrant_facts.yaml #{@facter_config_path}")
+            end
+           end
+
           run_puppet_apply
         end
 
@@ -213,7 +232,8 @@ module VagrantPlugins
 
           # Build up the custom facts if we have any
           facter = nil
-          if !config.facter.empty?
+          # Build up the (non-structured) custom facts if we have any
+          if !config.structured_facts && !config.facter.empty?
             facts = []
             config.facter.each do |key, value|
               facts << "FACTER_#{key}='#{value}'"
@@ -242,9 +262,11 @@ module VagrantPlugins
               env_vars.map! do |env_var_string|
                 "$env:#{env_var_string}"
               end
+              env_vars = env_vars.join("; ")
+              env_vars << ";"
+            else
+              env_vars = env_vars.join(" ")
             end
-
-            env_vars = env_vars.join(" ")
           end
 
           command = [
