@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 # This tests that VM is up as a linked clone
 shared_examples 'provider/linked_clone' do |provider, options|
   if !options[:box]
@@ -9,7 +12,7 @@ shared_examples 'provider/linked_clone' do |provider, options|
 
   before do
     environment.skeleton('linked_clone')
-    assert_execute('vagrant', 'box', 'add', 'basic', options[:box])
+    assert_execute('vagrant', 'box', 'add', 'box', options[:box])
   end
 
   after do
