@@ -1,9 +1,11 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "tmpdir"
 require "rubygems"
 
 # Gems
 require "checkpoint"
-require "webmock/rspec"
 require "rspec/its"
 
 # Require Vagrant itself so we can reference the proper
@@ -11,6 +13,12 @@ require "rspec/its"
 require "vagrant"
 require "vagrant/util/platform"
 
+# Include patches for fake ftp
+require "vagrant/patches/fake_ftp"
+
+# Be sure our proto messages are available
+Vagrant.load_vagrant_proto!
+
 # Add the test directory to the load path
 $:.unshift File.expand_path("../../", __FILE__)
 
@@ -33,7 +41,8 @@ VAGRANT_TEST_CWD = Dir.mktmpdir("vagrant-test-cwd")
 
 # Configure RSpec
 RSpec.configure do |c|
-  c.formatter = :documentation
+  c.formatter = :progress
+  c.color_mode = :on
 
   if Vagrant::Util::Platform.windows?
     c.filter_run_excluding :skip_windows
@@ -41,6 +50,10 @@ RSpec.configure do |c|
     c.filter_run_excluding :windows
   end
 
+  if !Vagrant::Util::Which.which("bsdtar")
+    c.filter_run_excluding :bsdtar
+  end
+
   c.after(:suite) do
     FileUtils.rm_rf(VAGRANT_TEST_CWD)
   end
