@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../../base", __FILE__)
 
 require Vagrant.source_root.join("plugins/commands/box/command/repackage")
@@ -18,7 +21,7 @@ describe VagrantPlugins::CommandBox::Command::Repackage do
   let(:action_runner) { double("action_runner") }
 
   before do
-    iso_env.stub(action_runner: action_runner)
+    allow(iso_env).to receive(:action_runner).and_return(action_runner)
   end
 
   context "with no arguments" do
@@ -47,9 +50,7 @@ describe VagrantPlugins::CommandBox::Command::Repackage do
   end
 
   context "with three arguments" do
-    it "repackages the box with the given provider" do
-      pending
-    end
+    it "repackages the box with the given provider"
   end
 
   context "with more than three arguments" do
