@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 require Vagrant.source_root.join("plugins/commands/cap/command")
@@ -47,5 +50,26 @@ describe VagrantPlugins::CommandCap::Command do
         expect(subject.execute).to eq(1)
       end
     end
+
+    context "runs against target vm" do
+      let(:argv) { ["provider", "foo", "--target-guest=dummy"] }
+      let(:cap) {
+        Class.new do
+          def self.foo(m)
+            true
+          end
+        end
+      }
+
+      before do
+        register_plugin do |p|
+          p.provider_capability(:dummy, :foo) { cap }
+        end
+      end
+
+      it "exits with 0 if it exists" do
+        expect(subject.execute).to eq(0)
+      end
+    end
   end
 end
