@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 require Vagrant.source_root.join("plugins/commands/list-commands/command")
@@ -19,7 +22,7 @@ describe VagrantPlugins::CommandListCommands::Command do
   subject { described_class.new(argv, iso_env) }
 
   before do
-    Vagrant.plugin("2").manager.stub(commands: commands)
+    allow(Vagrant.plugin("2").manager).to receive(:commands).and_return(commands)
   end
 
   describe "execute" do
@@ -28,7 +31,7 @@ describe VagrantPlugins::CommandListCommands::Command do
       commands[:bar] = [command_lambda("bar", 0), { primary: true }]
       commands[:baz] = [command_lambda("baz", 0), { primary: false }]
 
-      expect(iso_env.ui).to receive(:info).with { |message, opts|
+      expect(iso_env.ui).to receive(:info).with(any_args) { |message, opts|
         expect(message).to include("foo")
         expect(message).to include("bar")
         expect(message).to include("baz")
