@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../base"
 require_relative "../../../../../plugins/commands/package/command"
 
@@ -64,7 +67,7 @@ describe VagrantPlugins::CommandPackage::Command do
 
         it "packages default machine inside specified folder" do
           expect(package_command).to receive(:package_vm).with(
-            a_machine_named('default'), :output => "package-output-folder/default"
+            a_machine_named('default'), { output: "package-output-folder/default" }
           )
           package_command.execute
         end
@@ -96,7 +99,7 @@ describe VagrantPlugins::CommandPackage::Command do
         let(:argv){ ['--base', 'machine-id'] }
 
         it "packages vm defined within virtualbox" do
-          expect(package_command).to receive(:package_base).with(:base => 'machine-id')
+          expect(package_command).to receive(:package_base).with({ base: 'machine-id' })
           package_command.execute
         end
 
@@ -109,6 +112,24 @@ describe VagrantPlugins::CommandPackage::Command do
         end
       end
     end
+  end
 
+  describe "#package_vm" do
+    context "calling the package action" do
+      let(:options) { {output: "test.box"} }
+      let(:expected_options) { {"package.output"=>"test.box"} }
+      let(:machine) { double("machine") }
+      let(:tmp_dir) { "/home/user/.vagrant.d/tmp/vagrant-package" }
+      let(:env) { {"export.temp_dir"=>tmp_dir} }
+
+      it "ensures that the package tmp dir is cleaned up" do
+        allow(FileUtils).to receive(:rm_rf).and_return(true)
+        allow(machine).to receive(:action).with(:package, expected_options).
+          and_return(env)
+
+        expect(FileUtils).to receive(:rm_rf).with(tmp_dir)
+        package_command.send(:package_vm, machine, options)
+      end
+    end
   end
 end
