@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 require Vagrant.source_root.join("plugins/communicators/winrm/communicator")
@@ -8,12 +11,12 @@ describe VagrantPlugins::CommunicatorWinRM::Communicator do
   let(:winrm) { double("winrm", timeout: 1, host: nil, port: 5986, guest_port: 5986) }
   let(:config) { double("config", winrm: winrm) }
   let(:provider) { double("provider") }
-  let(:ui) { double("ui") }
+  let(:ui) { Vagrant::UI::Silent.new }
   let(:machine) { double("machine", config: config, provider: provider, ui: ui) }
   let(:shell) { double("shell") }
   let(:good_output) { WinRM::Output.new.tap { |out| out.exitcode = 0 } }
   let(:bad_output) { WinRM::Output.new.tap { |out| out.exitcode = 1 } }
-  
+
   subject do
     described_class.new(machine).tap do |comm|
       allow(comm).to receive(:create_shell).and_return(shell)
@@ -33,7 +36,6 @@ describe VagrantPlugins::CommunicatorWinRM::Communicator do
         allow(provider).to receive(:capability?).with(:winrm_info).and_return(false)
 
         # Get us through the detail prints
-        allow(ui).to receive(:detail)
         allow(shell).to receive(:host)
         allow(shell).to receive(:port)
         allow(shell).to receive(:username)
@@ -57,6 +59,13 @@ describe VagrantPlugins::CommunicatorWinRM::Communicator do
     end
   end
 
+  describe ".reset!" do
+    it "should create a new shell" do
+      expect(subject).to receive(:shell).with(true)
+      subject.reset!
+    end
+  end
+
   describe ".ready?" do
     it "returns true if hostname command executes without error" do
       expect(shell).to receive(:cmd).with("hostname").and_return({ exitcode: 0 })
@@ -68,6 +77,11 @@ describe VagrantPlugins::CommunicatorWinRM::Communicator do
       expect(subject.ready?).to be(false)
     end
 
+    it "returns false if hostname command fails with a WinRMNotReady error" do
+      expect(shell).to receive(:cmd).with("hostname").and_raise(VagrantPlugins::CommunicatorWinRM::Errors::WinRMNotReady)
+      expect(subject.ready?).to be(false)
+    end
+
     it "raises an error if hostname command fails with an unknown error" do
       expect(shell).to receive(:cmd).with("hostname").and_raise(Vagrant::Errors::VagrantError)
       expect { subject.ready? }.to raise_error(Vagrant::Errors::VagrantError)
