@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../../base"
 
 describe "VagrantPlugins::GuestDarwin::Cap::Halt" do
@@ -32,5 +35,12 @@ describe "VagrantPlugins::GuestDarwin::Cap::Halt" do
         cap.halt(machine)
       }.to_not raise_error
     end
+
+    it "ignores a Vagrant::Errors::SSHDisconnected" do
+      comm.stub_command("/sbin/shutdown -h now", raise: Vagrant::Errors::SSHDisconnected)
+      expect {
+        cap.halt(machine)
+      }.to_not raise_error
+    end
   end
 end
