@@ -1,4 +1,7 @@
-require File.expand_path("../../../../../base", __FILE__)
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
+require_relative "../../../../base"
 
 describe "VagrantPlugins::GuestLinux::Cap::MountSharedFolder" do
   let(:machine) { double("machine") }
