@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../../base"
 
 describe "VagrantPlugins::GuestRedHat::Cap:NFSClient" do
@@ -21,10 +24,10 @@ describe "VagrantPlugins::GuestRedHat::Cap:NFSClient" do
   describe ".nfs_client_install" do
     let(:cap) { caps.get(:nfs_client_install) }
 
-    it "installs rsync" do
+    it "installs nfs client" do
       cap.nfs_client_install(machine)
-      expect(comm.received_commands[0]).to match(/install nfs-utils nfs-utils-lib portmap/)
-      expect(comm.received_commands[0]).to match(/\/bin\/systemctl restart rpcbind nfs/)
+      expect(comm.received_commands[0]).to match(/install nfs-utils/)
+      expect(comm.received_commands[0]).to match(/\/bin\/systemctl restart rpcbind nfs-server/)
     end
   end
 end
