@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 require Vagrant.source_root.join("plugins/guests/windows/config")
@@ -23,7 +26,7 @@ describe VagrantPlugins::GuestWindows::Config do
       it "should not default #{attribute} if overridden" do
         subject.send("#{attribute}=".to_sym, 10)
         subject.finalize!
-        subject.send(attribute).should == 10
+        expect(subject.send(attribute)).to be(10)
       end
 
       it "should return error #{attribute} if nil" do
