@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../../base"
 require_relative "../../../../../../plugins/hosts/linux/cap/nfs"
 require_relative "../../../../../../lib/vagrant/util"
@@ -17,7 +20,7 @@ describe VagrantPlugins::HostLinux::Cap::NFS do
   end
   let(:exports_path){ VagrantPlugins::HostLinux::Cap::NFS::NFS_EXPORTS_PATH }
   let(:env){ double(:env) }
-  let(:ui){ double(:ui) }
+  let(:ui){ Vagrant::UI::Silent.new }
   let(:host){ double(:host) }
 
   before do
@@ -125,23 +128,22 @@ describe VagrantPlugins::HostLinux::Cap::NFS do
       allow(host).to receive(:capability).with(:nfs_apply_command).and_return("/bin/true")
       allow(host).to receive(:capability).with(:nfs_check_command).and_return("/bin/true")
       allow(host).to receive(:capability).with(:nfs_start_command).and_return("/bin/true")
-      allow(ui).to receive(:info)
       allow(Vagrant::Util::Subprocess).to receive(:execute).and_call_original
       allow(Vagrant::Util::Subprocess).to receive(:execute).with("sudo", "/bin/true").and_return(double(:result, exit_code: 0))
       allow(Vagrant::Util::Subprocess).to receive(:execute).with("/bin/true").and_return(double(:result, exit_code: 0))
     end
 
     it "should export new entries" do
-      cap.nfs_export(env, ui, SecureRandom.uuid, ["127.0.0.1"], "tmp" => {:hostpath => "/tmp"})
+      cap.nfs_export(env, ui, SecureRandom.uuid, ["127.0.0.1", "127.0.0.1"], "tmp" => {:hostpath => "/tmp"})
       exports_content = File.read(exports_path)
-      expect(exports_content).to match(/\/tmp.*127\.0\.0\.1/)
+      expect(exports_content.scan(/\/tmp.*127\.0\.0\.1/).length).to be(1)
     end
 
     it "should not remove existing entries" do
       File.write(exports_path, "/custom/directory hostname1(rw,sync,no_subtree_check)")
-      cap.nfs_export(env, ui, SecureRandom.uuid, ["127.0.0.1"], "tmp" => {:hostpath => "/tmp"})
+      cap.nfs_export(env, ui, SecureRandom.uuid, ["127.0.0.1", "127.0.0.1"], "tmp" => {:hostpath => "/tmp"})
       exports_content = File.read(exports_path)
-      expect(exports_content).to match(/\/tmp.*127\.0\.0\.1/)
+      expect(exports_content.scan(/\/tmp.*127\.0\.0\.1/).length).to be(1)
       expect(exports_content).to match(/\/custom\/directory.*hostname1/)
     end
 
@@ -188,7 +190,7 @@ EOH
                   :linux__nfs_options=>["rw","all_squash"]}}
       valid_id = SecureRandom.uuid
       content =<<-EOH
-\n# VAGRANT-BEGIN: #{Process.uid} #{valid_id}
+# VAGRANT-BEGIN: #{Process.uid} #{valid_id}
 "/home/vagrant" 127.0.0.1(rw,all_squash,anonuid=,anongid=,fsid=)
 "/newhome/otherproject" 127.0.0.1(rw,all_squash,anonuid=,anongid=,fsid=)
 # VAGRANT-END: #{Process.uid} #{valid_id}
@@ -206,7 +208,6 @@ EOH
     let(:cap){ caps.get(:nfs_prune) }
 
     before do
-      allow(ui).to receive(:info)
       allow(Vagrant::Util::Subprocess).to receive(:execute).with("mv", any_args).
         and_call_original
     end
@@ -269,14 +270,125 @@ EOH
       expect{ described_class.nfs_write_exports("new content") }.to raise_error(Vagrant::Errors::NFSExportsFailed)
     end
 
-    it "should retain existing file owner and group IDs" do
-      pending("investigate using a simulated FS to test")
-      test_with_simulated_fs
+    context "exports file modification" do
+      let(:tmp_stat) { double("tmp_stat", uid: 100, gid: 100, mode: tmp_mode) }
+      let(:tmp_mode) { 0 }
+      let(:exports_stat) {
+        double("stat", uid: exports_uid, gid: exports_gid,
+               mode: exports_mode, :directory? => true, :writable? => true,
+               :world_writable? => true, :sticky? => true)
+      }
+      let(:exports_uid) { -1 }
+      let(:exports_gid) { -1 }
+      let(:exports_mode) { 0 }
+      let(:new_exports_file) { double("new_exports_file", path: "/dev/null/exports") }
+      let(:new_exports_path) { new_exports_file.path }
+
+      before do
+        allow(File).to receive(:stat).and_call_original
+        allow(File).to receive(:join).with(Dir.tmpdir, "vagrant-exports").and_return(new_exports_path)
+        allow(File).to receive(:open).with(new_exports_path, "w+").and_return(new_exports_file)
+        allow(File).to receive(:stat).with(new_exports_path).and_return(tmp_stat)
+        allow(File).to receive(:stat).with(tmp_exports_path.to_s).and_return(exports_stat)
+        allow(new_exports_file).to receive(:puts)
+        allow(new_exports_file).to receive(:close)
+        allow(Vagrant::Util::Subprocess).to receive(:execute).and_return(Vagrant::Util::Subprocess::Result.new(0, "", ""))
+      end
+
+      it "should retain existing file owner and group IDs" do
+        expect(Vagrant::Util::Subprocess).to receive(:execute) { |*args|
+          expect(args).to include("sudo")
+          expect(args).to include("chown")
+        }.and_return(Vagrant::Util::Subprocess::Result.new(0, "", ""))
+        described_class.nfs_write_exports("new content")
+      end
+
+      it "should raise custom exception when chown fails" do
+        expect(Vagrant::Util::Subprocess).to receive(:execute) { |*args|
+          expect(args).to include("sudo")
+          expect(args).to include("chown")
+        }.and_return(Vagrant::Util::Subprocess::Result.new(1, "", ""))
+        expect { described_class.nfs_write_exports("new content") }.to raise_error(Vagrant::Errors::NFSExportsFailed)
+      end
+
+      context "when user has write access to exports file" do
+        let(:file_writable?) { true }
+        let(:dir_writable?) { false }
+        let(:exports_pathname) { double("exports_pathname", writable?: file_writable?, dirname: exports_dir_pathname) }
+        let(:exports_dir_pathname) { double("exports_dir_pathname", writable?: dir_writable?) }
+
+        before do
+          allow(File).to receive(:stat).and_return(exports_stat)
+          allow(File).to receive(:exist?).and_return(false)
+          allow(Pathname).to receive(:new).with(tmp_exports_path.to_s).and_return(exports_pathname)
+        end
+
+        it "should use sudo when moving new file" do
+          expect(Vagrant::Util::Subprocess).to receive(:execute) { |*args|
+            expect(args).to include("sudo")
+            expect(args).to include("mv")
+          }.and_return(Vagrant::Util::Subprocess::Result.new(0, "", ""))
+          described_class.nfs_write_exports("new content")
+        end
+
+        context "and write access to exports parent directory" do
+          let(:dir_writable?) { true }
+
+          it "should not use sudo when moving new file" do
+            expect(Vagrant::Util::Subprocess).to receive(:execute) { |*args|
+              expect(args).not_to include("sudo")
+              expect(args).to include("mv")
+            }.and_return(Vagrant::Util::Subprocess::Result.new(0, "", ""))
+            described_class.nfs_write_exports("new content")
+          end
+        end
+      end
+    end
+  end
+
+  describe ".modinfo_path" do
+    let(:cap){ VagrantPlugins::HostLinux::Cap::NFS }
+
+    context "with modinfo on PATH" do
+      before do
+        expect(Vagrant::Util::Which).to receive(:which).with("modinfo").and_return("/usr/bin/modinfo")
+      end
+
+      it "should use full path to modinfo" do
+        expect(cap.modinfo_path).to eq("/usr/bin/modinfo")
+      end
     end
 
-    it "should raise custom exception when chown fails" do
-      pending("investigate using a simulated FS to test")
-      test_with_simulated_fs
+    context "with modinfo at /sbin/modinfo" do
+      before do
+        expect(Vagrant::Util::Which).to receive(:which).with("modinfo").and_return(nil)
+        expect(File).to receive(:file?).with("/sbin/modinfo").and_return(true)
+      end
+
+      it "should use /sbin/modinfo" do
+        expect(cap.modinfo_path).to eq("/sbin/modinfo")
+      end
+    end
+
+    context "modinfo not found" do
+      before do
+        expect(Vagrant::Util::Which).to receive(:which).with("modinfo").and_return(nil)
+        expect(File).to receive(:file?).with("/sbin/modinfo").and_return(false)
+      end
+
+      it "should use modinfo" do
+        expect(cap.modinfo_path).to eq("modinfo")
+      end
+    end
+
+    context "with cached value for modinfo_path" do
+      before do
+        cap.instance_variable_set(:@_modinfo_path, "/usr/local/bin/modinfo")
+      end
+
+      it "should use cached value" do
+        expect(cap.modinfo_path).to eq("/usr/local/bin/modinfo")
+      end
     end
   end
 end
