@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../base"
 
 require Vagrant.source_root.join("plugins/providers/virtualbox/config")
@@ -43,6 +46,7 @@ describe VagrantPlugins::ProviderVirtualBox::Config do
     it { expect(subject.gui).to be(false) }
     it { expect(subject.name).to be_nil }
     it { expect(subject.functional_vboxsf).to be(true) }
+    it { expect(subject.default_nic_type).to be_nil }
 
     it "should have one NAT adapter" do
       expect(subject.network_adapters).to eql({
@@ -51,6 +55,17 @@ describe VagrantPlugins::ProviderVirtualBox::Config do
     end
   end
 
+  describe "#default_nic_type" do
+    let(:nic_type) { "custom" }
+
+    before do
+      subject.default_nic_type = nic_type
+      subject.finalize!
+    end
+
+    it { expect(subject.default_nic_type).to eq(nic_type) }
+  end
+
   describe "#merge" do
     let(:one) { described_class.new }
     let(:two) { described_class.new }
