@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../../base"
 
 require Vagrant.source_root.join("plugins/synced_folders/rsync/command/rsync_auto")
@@ -15,17 +18,17 @@ describe VagrantPlugins::SyncedFolderRSync::Command::RsyncAuto do
 
   let(:synced_folders_empty) { {} }
   let(:synced_folders_dupe) { {"1234":
-                               {type: "rsync",
-                                exclude: false,
-                                hostpath: "/Users/brian/code/vagrant-sandbox"},
-                               "5678":
-                               {type: "rsync",
-                                exclude: false,
-                                hostpath: "/Not/The/Same/Path"},
-                               "0912":
-                               {type: "rsync",
-                                exclude: false,
-                                hostpath: "/Users/brian/code/relative-dir"}}}
+    {type: "rsync",
+      exclude: false,
+      hostpath: "/Users/brian/code/vagrant-sandbox"},
+    "5678":
+    {type: "rsync",
+      exclude: false,
+      hostpath: "/Not/The/Same/Path"},
+    "0912":
+    {type: "rsync",
+      exclude: false,
+      hostpath: "/Users/brian/code/relative-dir"}}}
 
   let(:helper_class) { VagrantPlugins::SyncedFolderRSync::RsyncHelper }
 
@@ -42,9 +45,6 @@ describe VagrantPlugins::SyncedFolderRSync::Command::RsyncAuto do
       allow(m).to receive(:state).and_return(double("state", id: :not_created))
       allow(m).to receive(:env).and_return(iso_env)
       allow(m).to receive(:config).and_return(double("config"))
-
-
-      allow(m.ui).to receive(:error).and_return(nil)
     end
   end
 
@@ -63,31 +63,24 @@ describe VagrantPlugins::SyncedFolderRSync::Command::RsyncAuto do
     # the machines config file, they end up being a full path rather than a
     # relative path, and so these tests reflect that.
     # For reference:
-    # https://github.com/mitchellh/vagrant/blob/9c1b014536e61b332cfaa00774a87a240cce8ed9/lib/vagrant/action/builtin/synced_folders.rb#L45-L46
+    # https://github.com/hashicorp/vagrant/blob/9c1b014536e61b332cfaa00774a87a240cce8ed9/lib/vagrant/action/builtin/synced_folders.rb#L45-L46
     let(:config_synced_folders)  { {"/vagrant":
-                                   {type: "rsync",
-                                    exclude: false,
-                                    hostpath: "/Users/brian/code/vagrant-sandbox"},
-                                  "/vagrant/other-dir":
-                                   {type: "rsync",
-                                    exclude: false,
-                                    hostpath: "/Users/brian/code/vagrant-sandbox/other-dir"},
-                                  "/vagrant/relative-dir":
-                                   {type: "rsync",
-                                    exclude: false,
-                                    hostpath: "/Users/brian/code/relative-dir"}}}
+      {type: "rsync",
+        hostpath: "/Users/brian/code/vagrant-sandbox"},
+      "/vagrant/other-dir":
+      {type: "rsync",
+        hostpath: "/Users/brian/code/vagrant-sandbox/other-dir"},
+      "/vagrant/relative-dir":
+      {type: "rsync",
+        hostpath: "/Users/brian/code/relative-dir"}}}
 
     before do
-        allow(subject).to receive(:with_target_vms) { |&block| block.call machine }
-    end
-
-    it "does not sync folders outside of the cwd" do
-      allow(machine.ui).to receive(:info)
+      allow(subject).to receive(:with_target_vms) { |&block| block.call machine }
       allow(machine.state).to receive(:id).and_return(:created)
       allow(machine.env).to receive(:cwd).
         and_return("/Users/brian/code/vagrant-sandbox")
       allow(machine.provider).to receive(:capability?).and_return(false)
-      allow(machine.config).to receive(:vm).and_return(true)
+      allow(machine.config).to receive(:vm).and_return(double("vm"))
       allow(machine.config.vm).to receive(:synced_folders).and_return(config_synced_folders)
 
       allow(subject).to receive(:synced_folders).
@@ -95,17 +88,37 @@ describe VagrantPlugins::SyncedFolderRSync::Command::RsyncAuto do
       allow(helper_class).to receive(:rsync_single).and_return(true)
       allow(Vagrant::Util::Busy).to receive(:busy).and_return(true)
       allow(Listen).to receive(:to).and_return(true)
+    end
 
-
+    it "does not sync folders outside of the cwd" do
+      allow(machine.ui).to receive(:info).and_call_original
       expect(machine.ui).to receive(:info).
-        with("Not syncing /Not/The/Same/Path as it is not part of the current working directory.")
+        with("Not syncing /Not/The/Same/Path as it is not part of the current working directory.").
+        and_call_original
       expect(machine.ui).to receive(:info).
-        with("Watching: /Users/brian/code/vagrant-sandbox")
+        with("Watching: /Users/brian/code/vagrant-sandbox").
+        and_call_original
       expect(machine.ui).to receive(:info).
-        with("Watching: /Users/brian/code/relative-dir")
+        with("Watching: /Users/brian/code/relative-dir").
+        and_call_original
       expect(helper_class).to receive(:rsync_single)
 
-      subject.execute()
+      expect(Listen).to receive(:to).
+        with("/Users/brian/code/vagrant-sandbox",
+             "/Users/brian/code/relative-dir",
+             {:ignore=>[/.vagrant\//],
+                        :force_polling=>false})
+      subject.execute
+    end
+
+    context "with --rsync-chown option" do
+      let(:argv) { ["--rsync-chown"] }
+
+      it "should enable rsync_ownership on folder options" do
+        expect(helper_class).to receive(:rsync_single).
+          with(anything, anything, hash_including(rsync_ownership: true))
+        subject.execute
+      end
     end
   end
 
@@ -217,5 +230,49 @@ describe VagrantPlugins::SyncedFolderRSync::Command::RsyncAuto do
       expect { subject.callback(paths, m, a, r) }.
         to_not raise_error
     end
+
+    context "on failure" do
+      let(:machine) { machine_stub("m1") }
+      let(:opts) { double("opts_m1") }
+      let(:paths) { {"/foo" => [machine: machine, opts: opts]} }
+      let(:args) { [paths, ["/foo/bar"], [], []] }
+
+      before do
+        allow_any_instance_of(Vagrant::Errors::VagrantError).
+          to receive(:translate_error)
+      end
+
+      context "when rsync command fails" do
+        before do
+          expect(helper_class).to receive(:rsync_single).with(machine, machine.ssh_info, opts).
+            and_raise(Vagrant::Errors::RSyncError)
+        end
+
+        it "should notify on error" do
+          expect(machine.ui).to receive(:error).and_call_original
+          subject.callback(*args)
+        end
+
+        it "should not raise error" do
+          expect { subject.callback(*args) }.not_to raise_error
+        end
+      end
+
+      context "when rsync post command capability fails" do
+        before do
+          expect(helper_class).to receive(:rsync_single).with(machine, machine.ssh_info, opts).
+            and_raise(Vagrant::Errors::RSyncPostCommandError)
+        end
+
+        it "should notify on error" do
+          expect(machine.ui).to receive(:error).and_call_original
+          subject.callback(*args)
+        end
+
+        it "should not raise error" do
+          expect { subject.callback(*args) }.not_to raise_error
+        end
+      end
+    end
   end
 end
