@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "fileutils"
 require "pathname"
 require "tempfile"
@@ -97,8 +100,12 @@ module Unit
     # @param [String] provider
     # @return [Pathname]
     def box3(name, version, provider, **opts)
+      args = [name, version]
+      args << opts[:architecture].to_s if opts[:architecture]
+      args << provider.to_s
+
       # Create the directory for the box
-      box_dir = boxes_dir.join(name, version, provider.to_s)
+      box_dir = boxes_dir.join(*args)
       box_dir.mkpath
 
       # Create the metadata.json for it
@@ -132,8 +139,8 @@ module Unit
     # @return [Pathname] Path to the newly created box.
     def box1_file
       # Create a temporary directory to store our data we will tar up
-      td_source = Dir.mktmpdir
-      td_dest   = Dir.mktmpdir
+      td_source = Dir.mktmpdir("vagrant-box1-source")
+      td_dest   = Dir.mktmpdir("vagrant-box-1-dest")
 
       # Store the temporary directory so it is not deleted until
       # this instance is garbage collected.
@@ -177,8 +184,8 @@ module Unit
       }.merge(options[:metadata] || {})
 
       # Create a temporary directory to store our data we will tar up
-      td_source = Dir.mktmpdir
-      td_dest   = Dir.mktmpdir
+      td_source = Dir.mktmpdir("vagrant-box-2-source")
+      td_dest   = Dir.mktmpdir("vagrant-box-2-dest")
 
       # Store the temporary directory so it is not deleted until
       # this instance is garbage collected.
