@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 shared_context "synced folder actions" do
   # This creates a synced folder implementation.
   def impl(usable, name)
@@ -10,6 +13,10 @@ shared_context "synced folder actions" do
         raise "#{name}: usable" if raise_error && !usable
         usable
       end
+
+      define_method(:_initialize) do |machine, type|
+        true
+      end
     end
   end
 end
