@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../../../base"
 
 require "vagrant/util/template_renderer"
@@ -6,10 +9,13 @@ describe "templates/guests/freebsd/network_dhcp" do
   let(:template) { "guests/freebsd/network_dhcp" }
 
   it "renders the template" do
-    result = Vagrant::Util::TemplateRenderer.render(template, ifname: "vtneten0")
+    result = Vagrant::Util::TemplateRenderer.render(template, options: {
+      device: "eth1",
+    })
     expect(result).to eq <<-EOH.gsub(/^ {6}/, "")
       #VAGRANT-BEGIN
-      ifconfig_vtneten0="DHCP"
+      ifconfig_eth1="DHCP"
+      synchronous_dhclient="YES"
       #VAGRANT-END
     EOH
   end
