@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 describe Vagrant::Action::Builtin::Call do
@@ -10,6 +13,10 @@ describe Vagrant::Action::Builtin::Call do
         @app = app
       end
 
+      def self.name
+        "TestAction"
+      end
+
       define_method(:call) do |env|
         env[:data] << "#{data}_in"
         @app.call(env)
@@ -103,6 +110,10 @@ describe Vagrant::Action::Builtin::Call do
         env[:arg] = arg
       end
 
+      def self.name
+        "TestAction"
+      end
+
       def call(env); end
     end
 
@@ -126,6 +137,10 @@ describe Vagrant::Action::Builtin::Call do
         @env = env
       end
 
+      def self.name
+        "TestAction"
+      end
+
       def call(env)
         @app.call(env)
       end
@@ -137,6 +152,10 @@ describe Vagrant::Action::Builtin::Call do
         super
       end
 
+      def self.name
+        "TestAction"
+      end
+
       def recover(env)
         env[:steps] << :recover_A
       end
@@ -148,6 +167,10 @@ describe Vagrant::Action::Builtin::Call do
         super
       end
 
+      def self.name
+        "TestAction"
+      end
+
       def recover(env)
         env[:steps] << :recover_B
       end
