@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 describe Vagrant::Action::Builtin::EnvSet do
@@ -5,16 +8,16 @@ describe Vagrant::Action::Builtin::EnvSet do
   let(:env) { {} }
 
   it "should set the new environment" do
-    described_class.new(app, env, :foo => :bar).call(env)
+    described_class.new(app, env, foo: :bar).call(env)
 
-    env[:foo].should == :bar
+    expect(env[:foo]).to eq(:bar)
   end
 
   it "should call the next middleware" do
     callable = lambda { |env| env[:called] = env[:foo] }
 
-    env[:called].should be_nil
-    described_class.new(callable, env, :foo => :yep).call(env)
-    env[:called].should == :yep
+    expect(env[:called]).to be_nil
+    described_class.new(callable, env, foo: :yep).call(env)
+    expect(env[:called]).to eq(:yep)
   end
 end
