@@ -1,8 +1,11 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 describe Vagrant::Action::Builtin::GracefulHalt do
   let(:app) { lambda { |env| } }
-  let(:env) { { machine: machine, ui: ui } }
+  let(:env) { { machine: machine, ui: Vagrant::UI::Silent.new } }
   let(:machine) do
     result = double("machine")
     allow(result).to receive(:config).and_return(machine_config)
@@ -12,7 +15,7 @@ describe Vagrant::Action::Builtin::GracefulHalt do
   end
   let(:machine_config) do
     double("machine_config").tap do |top_config|
-      vm_config = double("machien_vm_config")
+      vm_config = double("machine_vm_config")
       allow(vm_config).to receive(:graceful_halt_timeout).and_return(10)
       allow(top_config).to receive(:vm).and_return(vm_config)
     end
