@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require_relative "../base"
 
 require "vagrant/cli"
@@ -28,6 +31,8 @@ describe Vagrant::CLI do
   end
 
   describe "#execute" do
+    let(:triggers) { double("triggers") }
+
     it "invokes help and exits with 1 if invalid command" do
       subject = described_class.new(["i-dont-exist"], env)
       expect(subject).to receive(:help).once
@@ -54,6 +59,38 @@ describe Vagrant::CLI do
       expect(checkpoint).to receive(:display)
       described_class.new(["destroy"], env).execute
     end
+
+    it "fires triggers, if enabled" do
+      allow(Vagrant::Util::Experimental).to receive(:feature_enabled?).
+        with("typed_triggers").and_return(true)
+      allow(triggers).to receive(:fire)
+      allow(triggers).to receive(:find).and_return([double("trigger-result")])
+
+      commands[:destroy] = [command_lambda("destroy", 42), {}]
+
+      allow(Vagrant::Plugin::V2::Trigger).to receive(:new).and_return(triggers)
+
+      subject = described_class.new(["destroy"], env)
+
+      expect(triggers).to receive(:fire).twice
+
+      expect(subject).not_to receive(:help)
+      expect(subject.execute).to eql(42)
+    end
+
+    it "does not fire triggers if disabled" do
+      allow(Vagrant::Util::Experimental).to receive(:feature_enabled?).
+        with("typed_triggers").and_return(false)
+
+      commands[:destroy] = [command_lambda("destroy", 42), {}]
+
+      subject = described_class.new(["destroy"], env)
+
+      expect(triggers).not_to receive(:fire)
+
+      expect(subject).not_to receive(:help)
+      expect(subject.execute).to eql(42)
+    end
   end
 
   describe "#help" do
