@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 describe Vagrant::Config::V1::Root do
@@ -5,27 +8,27 @@ describe Vagrant::Config::V1::Root do
 
   it "should provide access to config objects" do
     foo_class = Class.new
-    map       = { :foo => foo_class }
+    map       = { foo: foo_class }
 
     instance  = described_class.new(map)
     foo       = instance.foo
-    foo.should be_kind_of(foo_class)
-    instance.foo.should eql(foo)
+    expect(foo).to be_kind_of(foo_class)
+    expect(instance.foo).to eql(foo)
   end
 
   it "can be created with initial state" do
-    instance = described_class.new({}, { :foo => "bar" })
-    instance.foo.should == "bar"
+    instance = described_class.new({}, { foo: "bar" })
+    expect(instance.foo).to eq("bar")
   end
 
   it "should return internal state" do
     map      = { "foo" => Object, "bar" => Object }
     instance = described_class.new(map)
-    instance.__internal_state.should == {
+    expect(instance.__internal_state).to eq({
       "config_map" => map,
       "keys"       => {},
       "missing_key_calls" => Set.new
-    }
+    })
   end
 
   it "should record missing key calls" do
@@ -33,8 +36,8 @@ describe Vagrant::Config::V1::Root do
     instance.foo.bar = false
 
     keys = instance.__internal_state["missing_key_calls"]
-    keys.should be_kind_of(Set)
-    keys.length.should == 1
-    keys.include?("foo").should be
+    expect(keys).to be_kind_of(Set)
+    expect(keys.length).to eq(1)
+    expect(keys.include?("foo")).to be
   end
 end
