@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require "pathname"
 require "tmpdir"
 
@@ -23,6 +26,7 @@ describe Vagrant::Machine do
     double("box").tap do |b|
       allow(b).to receive(:name).and_return("foo")
       allow(b).to receive(:provider).and_return(:dummy)
+      allow(b).to receive(:architecture)
       allow(b).to receive(:version).and_return("1.0")
     end
   end
@@ -50,7 +54,8 @@ describe Vagrant::Machine do
 
   def new_provider_mock
     double("provider").tap do |obj|
-      allow(obj).to receive(:_initialize).and_return(nil)
+      allow(obj).to receive(:_initialize)
+        .with(provider_name, anything).and_return(nil)
       allow(obj).to receive(:machine_id_changed).and_return(nil)
       allow(obj).to receive(:state).and_return(Vagrant::MachineState.new(
         :created, "", ""))
@@ -76,6 +81,24 @@ describe Vagrant::Machine do
       expect(subject.id).to be_nil
     end
 
+    context "setting up triggers" do
+      before do
+        expect(provider).to receive(:_initialize) do |*args|
+          machine = args.last
+          @trigger_instance = machine.instance_variable_get(:@triggers)
+          true
+        end
+      end
+
+      it "should initialize the trigger object" do
+        subject = new_instance
+        expect(subject.instance_variable_get(:@triggers))
+          .to be_a(Vagrant::Plugin::V2::Trigger)
+        expect(subject.instance_variable_get(:@triggers))
+          .to eq(@trigger_instance)
+      end
+    end
+
     describe "as a base" do
       let(:base) { true}
 
@@ -246,51 +269,55 @@ describe Vagrant::Machine do
   end
 
   describe "#action" do
+    before do
+      allow(Vagrant::Plugin::Manager.instance).to receive(:installed_plugins).and_return({})
+    end
+
     it "should be able to run an action that exists" do
-      action_name = :up
+      action_name = :destroy
       called      = false
       callable    = lambda { |_env| called = true }
 
       expect(provider).to receive(:action).with(action_name).and_return(callable)
-      instance.action(:up)
+      instance.action(action_name)
       expect(called).to be
     end
 
     it "should provide the machine in the environment" do
-      action_name = :up
+      action_name = :destroy
       machine     = nil
       callable    = lambda { |env| machine = env[:machine] }
 
       allow(provider).to receive(:action).with(action_name).and_return(callable)
-      instance.action(:up)
+      instance.action(action_name)
 
       expect(machine).to eql(instance)
     end
 
     it "should pass any extra options to the environment" do
-      action_name = :up
+      action_name = :destroy
       foo         = nil
       callable    = lambda { |env| foo = env[:foo] }
 
       allow(provider).to receive(:action).with(action_name).and_return(callable)
-      instance.action(:up, foo: :bar)
+      instance.action(action_name, foo: :bar)
 
       expect(foo).to eq(:bar)
     end
 
     it "should pass any extra options to the environment as strings" do
-      action_name = :up
+      action_name = :destroy
       foo         = nil
       callable    = lambda { |env| foo = env["foo"] }
 
       allow(provider).to receive(:action).with(action_name).and_return(callable)
-      instance.action(:up, "foo" => :bar)
+      instance.action(action_name, "foo" => :bar)
 
       expect(foo).to eq(:bar)
     end
 
     it "should return the environment as a result" do
-      action_name = :up
+      action_name = :destroy
       callable    = lambda { |env| env[:result] = "FOO" }
 
       allow(provider).to receive(:action).with(action_name).and_return(callable)
@@ -300,7 +327,7 @@ describe Vagrant::Machine do
     end
 
     it "should raise an exception if the action is not implemented" do
-      action_name = :up
+      action_name = :destroy
 
       allow(provider).to receive(:action).with(action_name).and_return(nil)
 
@@ -309,10 +336,9 @@ describe Vagrant::Machine do
     end
 
     it 'should not warn if the machines cwd has not changed' do
-      initial_action_name  = :up
+      initial_action_name  = :destroy
       second_action_name  = :reload
       callable     = lambda { |_env| }
-      original_cwd = env.cwd.to_s
 
       allow(provider).to receive(:action).with(initial_action_name).and_return(callable)
       allow(provider).to receive(:action).with(second_action_name).and_return(callable)
@@ -326,7 +352,7 @@ describe Vagrant::Machine do
     end
 
     it 'should warn if the machine was last run under a different directory' do
-      action_name  = :up
+      action_name  = :destroy
       callable     = lambda { |_env| }
       original_cwd = env.cwd.to_s
 
@@ -347,11 +373,31 @@ describe Vagrant::Machine do
       end
     end
 
+    it 'should not warn if dirs are same but different cases' do
+      action_name  = :destroy
+      callable     = lambda { |_env| }
+      original_cwd = env.cwd.to_s
+
+      allow(provider).to receive(:action).with(action_name).and_return(callable)
+      allow(subject.ui).to receive(:warn)
+
+      instance.action(action_name)
+
+      expect(subject.ui).to_not have_received(:warn)
+
+      # In cygwin or other windows shell, it might have a path like
+      # c:/path and C:/path
+      # which are the same.
+      allow(env).to receive(:root_path).and_return(original_cwd.upcase)
+      expect(subject.ui).to_not have_received(:warn)
+      instance.action(action_name)
+    end
+
     context "if in a subdir" do
       let (:data_dir) { env.cwd }
 
       it 'should not warn if vagrant is run in subdirectory' do
-        action_name  = :up
+        action_name  = :destroy
         callable     = lambda { |_env| }
         original_cwd = env.cwd.to_s
 
@@ -535,6 +581,7 @@ describe Vagrant::Machine do
       box = double("box")
       allow(box).to receive(:name).and_return("foo")
       allow(box).to receive(:provider).and_return(:bar)
+      allow(box).to receive(:architecture)
       allow(box).to receive(:version).and_return("1.2.3")
       subject.box = box
 
@@ -554,6 +601,7 @@ describe Vagrant::Machine do
       expect(entry.extra_data["box"]).to eq({
         "name"     => box.name,
         "provider" => box.provider.to_s,
+        "architecture" => nil,
         "version"  => box.version,
       })
       env.machine_index.release(entry)
@@ -687,7 +735,9 @@ describe Vagrant::Machine do
         provider_ssh_info[:private_key_path] = nil
         instance.config.ssh.private_key_path = nil
 
-        expect(ssh_klass).to receive(:check_key_permissions).once.with(Pathname.new(instance.env.default_private_key_path.to_s))
+        instance.env.default_private_key_paths.each do |key_path|
+          expect(ssh_klass).to receive(:check_key_permissions).once.with(Pathname.new(key_path.to_s))
+        end
         instance.ssh_info
       end
 
@@ -731,7 +781,17 @@ describe Vagrant::Machine do
         instance.config.ssh.private_key_path = nil
 
         expect(instance.ssh_info[:private_key_path]).to eq(
-          [instance.env.default_private_key_path.to_s]
+          instance.env.default_private_key_paths
+        )
+      end
+
+      it "should return the default private key path with keys_only = false" do
+        provider_ssh_info[:private_key_path] = nil
+        instance.config.ssh.private_key_path = nil
+        instance.config.ssh.keys_only = false
+
+        expect(instance.ssh_info[:private_key_path]).to eq(
+          instance.env.default_private_key_paths
         )
       end
 
@@ -772,6 +832,26 @@ describe Vagrant::Machine do
         expect(instance.ssh_info[:private_key_path]).to eql([path])
       end
 
+      it "should return the remote_user when set" do
+        instance.config.ssh.remote_user = "remote-user"
+        expect(instance.ssh_info[:remote_user]).to eq("remote-user")
+      end
+
+      it "should return the config when set" do
+        instance.config.ssh.config = "/path/to/ssh_config"
+        expect(instance.ssh_info[:config]).to eq("/path/to/ssh_config")
+      end
+
+      it "should return the default connect_timeout" do
+        expect(instance.ssh_info[:connect_timeout]).
+          to eq(VagrantPlugins::Kernel_V2::SSHConnectConfig::DEFAULT_SSH_CONNECT_TIMEOUT)
+      end
+
+      it "should return the connect_timeout when set" do
+        instance.config.ssh.connect_timeout = 2
+        expect(instance.ssh_info[:connect_timeout]).to eq(2)
+      end
+
       context "with no data dir" do
         let(:base)     { true }
         let(:data_dir) { nil }
@@ -791,7 +871,7 @@ describe Vagrant::Machine do
           expect(instance.ssh_info[:keys_only]).to be(true)
         end
         it "verify_host_key should be default" do
-          expect(instance.ssh_info[:verify_host_key]).to be(false)
+          expect(instance.ssh_info[:verify_host_key]).to be(:never)
         end
         it "extra_args should be nil" do
           expect(instance.ssh_info[:extra_args]).to be(nil)
@@ -846,6 +926,33 @@ describe Vagrant::Machine do
     end
   end
 
+  describe "#recover_machine" do
+    it "does not recover a machine already in the index" do
+      subject.id = "foo"
+      expected_entry = env.machine_index.get(subject.index_uuid)
+      env.machine_index.release(expected_entry)
+
+      entry = subject.recover_machine(:running)
+      expect(entry.id).to eq(expected_entry.id)
+      # Ensure entry is not locked
+      env.machine_index.get(subject.index_uuid)
+    end
+
+    it "recovers a machine" do
+      instance = new_instance
+      instance.id = "foo"
+
+      entry = instance.recover_machine(:running)
+      expect(entry.id).to eq(instance.index_uuid)
+      # Ensure entry is not locked
+      env.machine_index.get(entry.id)
+      env.machine_index.release(entry)
+
+      query_entry = env.machine_index.get(instance.index_uuid)
+      expect(entry.id).to eq(query_entry.id)
+    end
+  end
+
   describe "#with_ui" do
     it "temporarily changes the UI" do
       ui = Object.new
@@ -859,4 +966,62 @@ describe Vagrant::Machine do
       expect(subject.ui).to_not equal(ui)
     end
   end
+
+  describe "#reload" do
+    context "when ID is unset and id file does not exist" do
+      it "should remain nil" do
+        expect(subject.id).to be_nil
+        instance.reload
+        expect(subject.id).to be_nil
+      end
+    end
+
+    context "when id file is set" do
+      let(:id_content) { "test-machine-id" }
+
+      before do
+        id_file = subject.data_dir.join("id")
+        File.write(id_file.to_s, id_content)
+      end
+
+      it "should update the machine id" do
+        expect(subject.id).to be_nil
+        instance.reload
+        expect(subject.id).to eq(id_content)
+      end
+
+      it "should notify of the id change when provider is set" do
+        expect(provider).to receive(:machine_id_changed)
+        instance.reload
+      end
+
+      context "when id file content includes whitespace" do
+        let(:id_content) { "   test-machine-id\n" }
+
+        it "should remove all whitespace" do
+          instance.reload
+          expect(instance.id).to eq("test-machine-id")
+        end
+      end
+
+      context "when id file content is all whitespace" do
+        let(:id_content) { "\0\0\0\0\0\0" }
+
+        it "should not update the id" do
+          expect(instance.id).to be_nil
+          instance.reload
+          expect(instance.id).to be_nil
+        end
+      end
+
+      context "when id is already set to value in id file" do
+        it "should not notify of id change" do
+          instance.instance_variable_set(:@id, id_content)
+          expect(provider).not_to receive(:machine_id_changed)
+          instance.reload
+          expect(instance.id).to eq(id_content)
+        end
+      end
+    end
+  end
 end
