@@ -1,3 +1,6 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 
 describe Vagrant::Plugin::V1::Provider do
@@ -5,14 +8,14 @@ describe Vagrant::Plugin::V1::Provider do
   let(:instance) { described_class.new(machine) }
 
   it "should return nil by default for actions" do
-    instance.action(:whatever).should be_nil
+    expect(instance.action(:whatever)).to be_nil
   end
 
   it "should return nil by default for ssh info" do
-    instance.ssh_info.should be_nil
+    expect(instance.ssh_info).to be_nil
   end
 
   it "should return nil by default for state" do
-    instance.state.should be_nil
+    expect(instance.state).to be_nil
   end
 end
