@@ -1,5 +1,9 @@
+# Copyright (c) HashiCorp, Inc.
+# SPDX-License-Identifier: BUSL-1.1
+
 require File.expand_path("../../../../base", __FILE__)
 require 'optparse'
+require 'vagrant/machine_index'
 
 describe Vagrant::Plugin::V2::Command do
   include_context "unit"
@@ -46,6 +50,12 @@ describe Vagrant::Plugin::V2::Command do
         to raise_error(Vagrant::Errors::CLIInvalidOptions)
     end
 
+    it "raises an error if ambiguous options are given" do
+      instance = klass.new(["-provision"], nil)
+      expect { instance.parse_options(OptionParser.new) }.
+        to raise_error(Vagrant::Errors::CLIInvalidOptions)
+    end
+
     it "raises an error if options without a value are given" do
       opts = OptionParser.new do |o|
         o.on("--provision-with x,y,z", Array, "Example") { |f| }
@@ -78,7 +88,7 @@ describe Vagrant::Plugin::V2::Command do
     subject { instance }
 
     it "should raise an exception if a root_path is not available" do
-      environment.stub(root_path: nil)
+      allow(environment).to receive(:root_path).and_return(nil)
 
       expect { instance.with_target_vms }.
         to raise_error(Vagrant::Errors::NoEnvironmentError)
@@ -86,16 +96,18 @@ describe Vagrant::Plugin::V2::Command do
 
     it "should yield every VM in order if no name is given" do
       foo_vm = double("foo")
-      foo_vm.stub(name: "foo", provider: :foobarbaz)
-      foo_vm.stub(ui: Vagrant::UI::Silent.new)
-      foo_vm.stub(state: nil)
+      allow(foo_vm).to receive(:name).and_return("foo")
+      allow(foo_vm).to receive(:provider).and_return(:foobarbaz)
+      allow(foo_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(foo_vm).to receive(:state).and_return(nil)
 
       bar_vm = double("bar")
-      bar_vm.stub(name: "bar", provider: :foobarbaz)
-      bar_vm.stub(ui: Vagrant::UI::Silent.new)
-      bar_vm.stub(state: nil)
+      allow(bar_vm).to receive(:name).and_return("bar")
+      allow(bar_vm).to receive(:provider).and_return(:foobarbaz)
+      allow(bar_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(bar_vm).to receive(:state).and_return(nil)
 
-      environment.stub(machine_names: [:foo, :bar])
+      allow(environment).to receive(:machine_names).and_return([:foo, :bar])
       allow(environment).to receive(:machine).with(:foo, environment.default_provider).and_return(foo_vm)
       allow(environment).to receive(:machine).with(:bar, environment.default_provider).and_return(bar_vm)
 
@@ -108,7 +120,7 @@ describe Vagrant::Plugin::V2::Command do
     end
 
     it "raises an exception if the named VM doesn't exist" do
-      environment.stub(machine_names: [:default])
+      allow(environment).to receive(:machine_names).and_return([:default])
       allow(environment).to receive(:machine).with(:foo, anything).and_return(nil)
 
       expect { instance.with_target_vms("foo") }.
@@ -117,9 +129,10 @@ describe Vagrant::Plugin::V2::Command do
 
     it "yields the given VM if a name is given" do
       foo_vm = double("foo")
-      foo_vm.stub(name: "foo", provider: :foobarbaz)
-      foo_vm.stub(ui: Vagrant::UI::Silent.new)
-      foo_vm.stub(state: nil)
+      allow(foo_vm).to receive(:name).and_return("foo")
+      allow(foo_vm).to receive(:provider).and_return(:foobarbaz)
+      allow(foo_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(foo_vm).to receive(:state).and_return(nil)
 
       allow(environment).to receive(:machine).with(:foo, environment.default_provider).and_return(foo_vm)
 
@@ -130,9 +143,10 @@ describe Vagrant::Plugin::V2::Command do
 
     it "calls state after yielding the vm to update the machine index" do
       foo_vm = double("foo")
-      foo_vm.stub(name: "foo", provider: :foobarbaz)
-      foo_vm.stub(ui: Vagrant::UI::Silent.new)
-      foo_vm.stub(state: nil)
+      allow(foo_vm).to receive(:name).and_return("foo")
+      allow(foo_vm).to receive(:provider).and_return(:foobarbaz)
+      allow(foo_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(foo_vm).to receive(:state).and_return(nil)
 
       allow(environment).to receive(:machine).with(:foo, environment.default_provider).and_return(foo_vm)
 
@@ -141,13 +155,48 @@ describe Vagrant::Plugin::V2::Command do
       instance.with_target_vms("foo") { |vm| vms << vm }
     end
 
+    it "does not recover the vm if it has no uuid" do
+      foo_vm = double("foo")
+      provider = :foobarbaz
+      state_id = :some_state
+      allow(foo_vm).to receive(:name).and_return("foo")
+      allow(foo_vm).to receive(:provider).and_return(provider)
+      allow(foo_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(foo_vm).to receive(:state).and_return(double("state", id: state_id))
+      allow(foo_vm).to receive(:index_uuid).and_return(nil)
+      allow(environment).to receive(:machine).with(:foo, provider).and_return(foo_vm)
+      
+      expect(foo_vm).not_to receive(:recover_machine).with(state_id)
+      vms = []
+      instance.with_target_vms("foo", provider: provider) { |vm| vms << vm }
+      expect(vms).to eq([foo_vm])
+    end
+
+    it "recovers the vm" do
+      foo_vm = double("foo")
+      provider = :foobarbaz
+      state_id = :some_state
+      allow(foo_vm).to receive(:name).and_return("foo")
+      allow(foo_vm).to receive(:provider).and_return(provider)
+      allow(foo_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(foo_vm).to receive(:state).and_return(double("state", id: state_id))
+      allow(foo_vm).to receive(:index_uuid).and_return("someuuid")
+      allow(environment).to receive(:machine).with(:foo, provider).and_return(foo_vm)
+      
+      expect(foo_vm).to receive(:recover_machine).with(state_id)
+      vms = []
+      instance.with_target_vms("foo", provider: provider) { |vm| vms << vm }
+      expect(vms).to eq([foo_vm])
+    end
+
     it "yields the given VM with proper provider if given" do
       foo_vm = double("foo")
       provider = :foobarbaz
 
-      foo_vm.stub(name: "foo", provider: provider)
-      foo_vm.stub(ui: Vagrant::UI::Silent.new)
-      foo_vm.stub(state: nil)
+      allow(foo_vm).to receive(:name).and_return("foo")
+      allow(foo_vm).to receive(:provider).and_return(provider)
+      allow(foo_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(foo_vm).to receive(:state).and_return(nil)
       allow(environment).to receive(:machine).with(:foo, provider).and_return(foo_vm)
 
       vms = []
@@ -158,7 +207,7 @@ describe Vagrant::Plugin::V2::Command do
     it "should raise an exception if an active machine exists with a different provider" do
       name = :foo
 
-      environment.stub(active_machines: [[name, :vmware]])
+      allow(environment).to receive(:active_machines).and_return([[name, :vmware]])
       expect { instance.with_target_vms(name.to_s, provider: :foo) }.
         to raise_error Vagrant::Errors::ActiveMachineWithDifferentProvider
     end
@@ -168,11 +217,12 @@ describe Vagrant::Plugin::V2::Command do
       provider = :vmware
       vmware_vm = double("vmware_vm")
 
-      environment.stub(active_machines: [[name, provider]])
+      allow(environment).to receive(:active_machines).and_return([[name, provider]])
       allow(environment).to receive(:machine).with(name, provider).and_return(vmware_vm)
-      vmware_vm.stub(name: name, provider: provider)
-      vmware_vm.stub(ui: Vagrant::UI::Silent.new)
-      vmware_vm.stub(state: nil)
+      allow(vmware_vm).to receive(:name).and_return(name)
+      allow(vmware_vm).to receive(:provider).and_return(provider)
+      allow(vmware_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(vmware_vm).to receive(:state).and_return(nil)
 
       vms = []
       instance.with_target_vms(name.to_s) { |vm| vms << vm }
@@ -184,10 +234,12 @@ describe Vagrant::Plugin::V2::Command do
       provider = :vmware
       vmware_vm = double("vmware_vm")
 
-      environment.stub(active_machines: [[name, provider]])
+      allow(environment).to receive(:active_machines).and_return([[name, provider]])
       allow(environment).to receive(:machine).with(name, provider).and_return(vmware_vm)
-      vmware_vm.stub(name: name, provider: provider, ui: Vagrant::UI::Silent.new)
-      vmware_vm.stub(state: nil)
+      allow(vmware_vm).to receive(:name).and_return(name)
+      allow(vmware_vm).to receive(:provider).and_return(provider)
+      allow(vmware_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(vmware_vm).to receive(:state).and_return(nil)
 
       vms = []
       instance.with_target_vms(name.to_s, provider: provider) { |vm| vms << vm }
@@ -199,9 +251,10 @@ describe Vagrant::Plugin::V2::Command do
       machine = double("machine")
 
       allow(environment).to receive(:machine).with(name, environment.default_provider).and_return(machine)
-      machine.stub(name: name, provider: environment.default_provider)
-      machine.stub(ui: Vagrant::UI::Silent.new)
-      machine.stub(state: nil)
+      allow(machine).to receive(:name).and_return(name)
+      allow(machine).to receive(:provider).and_return(environment.default_provider)
+      allow(machine).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(machine).to receive(:state).and_return(nil)
 
       results = []
       instance.with_target_vms(name.to_s) { |m| results << m }
@@ -213,13 +266,14 @@ describe Vagrant::Plugin::V2::Command do
       provider = :vmware
       vmware_vm = double("vmware_vm")
 
-      environment.stub(active_machines: [[name, provider]])
+      allow(environment).to receive(:active_machines).and_return([[name, provider]])
       allow(environment).to receive(:machine).with(name, provider).and_return(vmware_vm)
-      environment.stub(machine_names: [])
-      environment.stub(primary_machine_name: name)
-      vmware_vm.stub(name: name, provider: provider)
-      vmware_vm.stub(ui: Vagrant::UI::Silent.new)
-      vmware_vm.stub(state: nil)
+      allow(environment).to receive(:machine_names).and_return([])
+      allow(environment).to receive(:primary_machine_name).and_return(name)
+      allow(vmware_vm).to receive(:name).and_return(name)
+      allow(vmware_vm).to receive(:provider).and_return(provider)
+      allow(vmware_vm).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(vmware_vm).to receive(:state).and_return(nil)
 
       vms = []
       instance.with_target_vms(nil, single_target: true) { |vm| vms << vm }
@@ -230,13 +284,14 @@ describe Vagrant::Plugin::V2::Command do
       name = :foo
       machine = double("machine")
 
-      environment.stub(active_machines: [])
+      allow(environment).to receive(:active_machines).and_return([])
       allow(environment).to receive(:machine).with(name, environment.default_provider).and_return(machine)
-      environment.stub(machine_names: [])
-      environment.stub(primary_machine_name: name)
-      machine.stub(name: name, provider: environment.default_provider)
-      machine.stub(ui: Vagrant::UI::Silent.new)
-      machine.stub(state: nil)
+      allow(environment).to receive(:machine_names).and_return([])
+      allow(environment).to receive(:primary_machine_name).and_return(name)
+      allow(machine).to receive(:name).and_return(name)
+      allow(machine).to receive(:provider).and_return(environment.default_provider)
+      allow(machine).to receive(:ui).and_return(Vagrant::UI::Silent.new)
+      allow(machine).to receive(:state).and_return(nil)
 
       vms = []
       instance.with_target_vms(nil, single_target: true) { |vm| vms << machine }
@@ -255,7 +310,7 @@ describe Vagrant::Plugin::V2::Command do
       other_machine.id = "foo"
 
       # Make sure we don't have a root path, to test
-      environment.stub(root_path: nil)
+      allow(environment).to receive(:root_path).and_return(nil)
 
       results = []
       subject.with_target_vms(other_machine.index_uuid) { |m| results << m }
@@ -282,7 +337,7 @@ describe Vagrant::Plugin::V2::Command do
       FileUtils.rm_rf(iso_env.workdir)
 
       # Make sure we don't have a root path, to test
-      environment.stub(root_path: nil)
+      allow(environment).to receive(:root_path).and_return(nil)
 
       # Run the command
       expect {
